<?php
/**
 * Theme functions and definitions
 *
 * @package Home Renovation
 */

if ( ! function_exists( 'home_renovation_enqueue_styles' ) ) :
	/**
	 * Load assets.
	 *
	 * @since 1.0.0
	 */
	function home_renovation_enqueue_styles() {
		wp_enqueue_style( 'construction-firm-style-parent', get_template_directory_uri() . '/style.css' );
		wp_enqueue_style( 'home-renovation-style', get_stylesheet_directory_uri() . '/style.css', array( 'construction-firm-style-parent' ), '1.0.0' );

		// Theme Customize CSS.
		require get_parent_theme_file_path( 'inc/extra_customization.php' );
		wp_add_inline_style( 'home-renovation-style',$construction_firm_custom_style );
	}
endif;
add_action( 'wp_enqueue_scripts', 'home_renovation_enqueue_styles', 99 );

function home_renovation_setup() {
	add_theme_support( 'align-wide' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( "responsive-embeds" );
	add_theme_support( "wp-block-styles" );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	add_theme_support('custom-background',array(
		'default-color' => 'ffffff',
	));
	add_image_size( 'home-renovation-featured-image', 2000, 1200, true );
	add_image_size( 'home-renovation-thumbnail-avatar', 100, 100, true );

	$GLOBALS['content_width'] = 525;
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'home-renovation' ),
	) );

	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo', array(
		'width'       => 250,
		'height'      => 250,
		'flex-width'  => true,
	) );

	/*
	* This theme styles the visual editor to resemble the theme style,
	* specifically font, colors, and column width.
	*/
	add_editor_style( array( 'assets/css/editor-style.css', construction_firm_fonts_url() ) );
}
add_action( 'after_setup_theme', 'home_renovation_setup' );

function home_renovation_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'home-renovation' ),
		'id'            => 'sidebar-1',
		'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and archive pages.', 'home-renovation' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'home-renovation' ),
		'id'            => 'sidebar-2',
		'description'   => __( 'Add widgets here to appear in your pages and posts', 'home-renovation' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 1', 'home-renovation' ),
		'id'            => 'footer-1',
		'description'   => __( 'Add widgets here to appear in your footer.', 'home-renovation' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 2', 'home-renovation' ),
		'id'            => 'footer-2',
		'description'   => __( 'Add widgets here to appear in your footer.', 'home-renovation' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 3', 'home-renovation' ),
		'id'            => 'footer-3',
		'description'   => __( 'Add widgets here to appear in your footer.', 'home-renovation' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 4', 'home-renovation' ),
		'id'            => 'footer-4',
		'description'   => __( 'Add widgets here to appear in your footer.', 'home-renovation' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'home_renovation_widgets_init' );

function home_renovation_customize_register() {
  	global $wp_customize;

  	$wp_customize->remove_section( 'construction_firm_pro' );
}
add_action( 'customize_register', 'home_renovation_customize_register', 11 );

function home_renovation_sanitize_dropdown_pages( $page_id, $setting ) {
	$page_id = absint( $page_id );
	return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}

function home_renovation_customize( $wp_customize ) {

	wp_enqueue_style('customizercustom_css', esc_url( get_stylesheet_directory_uri() ). '/assets/css/customizer.css');

	$wp_customize->add_section('home_renovation_pro', array(
		'title'    => __('UPGRADE RENOVATION PREMIUM', 'home-renovation'),
		'priority' => 1,
	));

	$wp_customize->add_setting('home_renovation_pro', array(
		'default'           => null,
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control(new Home_Renovation_Pro_Control($wp_customize, 'home_renovation_pro', array(
		'label'    => __('HOME RENOVATION PREMIUM', 'home-renovation'),
		'section'  => 'home_renovation_pro',
		'settings' => 'home_renovation_pro',
		'priority' => 1,
	)));
}
add_action( 'customize_register', 'home_renovation_customize' );

function home_renovation_enqueue_comments_reply() {
  if( is_singular() && comments_open() && ( get_option( 'thread_comments' ) == 1) ) {
    // Load comment-reply.js (into footer)
    wp_enqueue_script( 'comment-reply', '/wp-includes/js/comment-reply.min.js', array(), false, true );
  }
}
add_action(  'wp_enqueue_scripts', 'home_renovation_enqueue_comments_reply' );

define('HOME_RENOVATION_PRO_LINK',__('https://www.ovationthemes.com/wordpress/home-services-wordpress-theme/','home-renovation'));

/* Pro control */
if (class_exists('WP_Customize_Control') && !class_exists('Home_Renovation_Pro_Control')):
    class Home_Renovation_Pro_Control extends WP_Customize_Control{

    public function render_content(){?>
        <label style="overflow: hidden; zoom: 1;">
            <div class="col-md upsell-btn">
                <a href="<?php echo esc_url( HOME_RENOVATION_PRO_LINK ); ?>" target="blank" class="btn btn-success btn"><?php esc_html_e('UPGRADE RENOVATION PREMIUM','home-renovation');?> </a>
            </div>
            <div class="col-md">
                <img class="home_renovation_img_responsive " src="<?php echo esc_url( get_stylesheet_directory_uri() ); ?>/screenshot.png">
            </div>
            <div class="col-md">
                <h3 style="margin-top:10px; margin-left: 20px; text-decoration:underline; color:#333;"><?php esc_html_e('RENOVATION PREMIUM - Features', 'home-renovation'); ?></h3>
                <ul style="padding-top:10px">
                    <li class="upsell-home_renovation"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Responsive Design', 'home-renovation');?> </li>
                    <li class="upsell-home_renovation"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Boxed or fullwidth layout', 'home-renovation');?> </li>
                    <li class="upsell-home_renovation"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Shortcode Support', 'home-renovation');?> </li>
                    <li class="upsell-home_renovation"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Demo Importer', 'home-renovation');?> </li>
                    <li class="upsell-home_renovation"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Section Reordering', 'home-renovation');?> </li>
                    <li class="upsell-home_renovation"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Contact Page Template', 'home-renovation');?> </li>
                    <li class="upsell-home_renovation"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Multiple Blog Layouts', 'home-renovation');?> </li>
                    <li class="upsell-home_renovation"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Unlimited Color Options', 'home-renovation');?> </li>
                    <li class="upsell-home_renovation"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Designed with HTML5 and CSS3', 'home-renovation');?> </li>
                    <li class="upsell-home_renovation"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Customizable Design & Code', 'home-renovation');?> </li>
                    <li class="upsell-home_renovation"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Cross Browser Support', 'home-renovation');?> </li>
                    <li class="upsell-home_renovation"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Detailed Documentation Included', 'home-renovation');?> </li>
                    <li class="upsell-home_renovation"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Stylish Custom Widgets', 'home-renovation');?> </li>
                    <li class="upsell-home_renovation"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Patterns Background', 'home-renovation');?> </li>
                    <li class="upsell-home_renovation"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('WPML Compatible (Translation Ready)', 'home-renovation');?> </li>
                    <li class="upsell-home_renovation"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Woo-commerce Compatible', 'home-renovation');?> </li>
                    <li class="upsell-home_renovation"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Full Support', 'home-renovation');?> </li>
                    <li class="upsell-home_renovation"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('10+ Sections', 'home-renovation');?> </li>
                    <li class="upsell-home_renovation"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Live Customizer', 'home-renovation');?> </li>
                    <li class="upsell-home_renovation"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('AMP Ready', 'home-renovation');?> </li>
                    <li class="upsell-home_renovation"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Clean Code', 'home-renovation');?> </li>
                    <li class="upsell-home_renovation"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('SEO Friendly', 'home-renovation');?> </li>
                    <li class="upsell-home_renovation"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Supper Fast', 'home-renovation');?> </li>
                </ul>
            </div>
            <div class="col-md upsell-btn upsell-btn-bottom">
                <a href="<?php echo esc_url( HOME_RENOVATION_PRO_LINK ); ?>" target="blank" class="btn btn-success btn"><?php esc_html_e('UPGRADE RENOVATION PREMIUM','home-renovation');?> </a>
            </div>
        </label>
    <?php } }
endif;

if ( ! defined( 'CONSTRUCTION_FIRM_SUPPORT' ) ) {
define('CONSTRUCTION_FIRM_SUPPORT',__('https://wordpress.org/support/theme/home-renovation','home-renovation'));
}
if ( ! defined( 'CONSTRUCTION_FIRM_REVIEW' ) ) {
define('CONSTRUCTION_FIRM_REVIEW',__('https://wordpress.org/support/theme/home-renovation/reviews/#new-post','home-renovation'));
}
if ( ! defined( 'CONSTRUCTION_FIRM_LIVE_DEMO' ) ) {
define('CONSTRUCTION_FIRM_LIVE_DEMO',__('https://www.ovationthemes.com/demos/home-renovation/','home-renovation'));
}
if ( ! defined( 'CONSTRUCTION_FIRM_BUY_PRO' ) ) {
define('CONSTRUCTION_FIRM_BUY_PRO',__('https://www.ovationthemes.com/wordpress/home-services-wordpress-theme/','home-renovation'));
}
if ( ! defined( 'CONSTRUCTION_FIRM_PRO_DOC' ) ) {
define('CONSTRUCTION_FIRM_PRO_DOC',__('https://www.ovationthemes.com/docs/ot-home-renovation-pro-doc','home-renovation'));
}
if ( ! defined( 'CONSTRUCTION_FIRM_THEME_NAME' ) ) {
define('CONSTRUCTION_FIRM_THEME_NAME',__('Premium Renovation Theme','home-renovation'));
}